// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <ClanLib/clanlib.h>
#include <ClanLib/clanlayer2.h>
#include <assert.h>

#include "Background.hh"
#include "globals.hh"

Background::Background(background_data bg)
{
  scroll_x = bg.scroll_x;
  scroll_y = bg.scroll_y;

  bg_surface = CL_Res_Surface::load(bg.desc.res_name.c_str(), *resource());
  
  if (!bg_surface) {
    cout << bg.desc.res_name << ": Could not load file" << endl;
    exit(EXIT_FAILURE);
  }
}

Background::~Background()
{
  //  delete bg_surface;
}

void
Background::draw()
{
  assert(bg_surface);

  for(int y=0; y <= CL_Display::get_height(); y += bg_surface->get_height())
    for(int x=0; x < CL_Display::get_width(); x += bg_surface->get_width())
      bg_surface->put_screen(x, y);
}

void
Background::draw_offset(int x_of, int y_of, double s = 1.0)
{
  int start_x = 0;
  int start_y = 0;

  start_x = bg_surface->get_width() + (x_of / 2);

  if (start_x > 0)
    start_x = 0 - bg_surface->get_width() + start_x;

  assert(bg_surface);
  // BUG: This function works, but I don't know why =?^)
  // Maybe I should rewrite it.
  if (s == 1.0) {
    for(int y = (y_of/2); y < CL_Display::get_height()- 54; y += bg_surface->get_height()) {
      for(int x = start_x; x < CL_Display::get_width(); x += bg_surface->get_width()) {
	bg_surface->put_screen(x, y);
      }
    }
  } else {
    for(int y=(y_of/2); y < CL_Display::get_height()- 54; y += (int)(bg_surface->get_height() * s)) {
      for(int x = start_x; x < CL_Display::get_width(); x += (int)(bg_surface->get_width() * s)) {
	bg_surface->put_screen(x, y,
			       (int)(bg_surface->get_width() * s),
			       (int)(bg_surface->get_height() * s)
			       );
      }
    }
  }
}

/* EOF */
