// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cstdio>
#include "Hotspot.hh"
#include "globals.hh"
#include "PLF.hh"

map<string, hotspot_pref> Hotspot::offset;

Hotspot::Hotspot(hotspot_data spot)
{
  int of_x, of_y;
  hotspot_pref p = offset[spot.desc.res_name];
  
  of_x = p.y_pos;
  of_y = p.y_pos;
  speed = p.speed;

  if (verbose) {
    cout << "Hotspot: Offset: "
	 << spot.desc.res_name << " " 
	 << of_x << " " 
	 << of_y << " " 
	 << speed <<  endl;
  }
  
  x_pos = spot.x_pos - of_x;
  y_pos = spot.y_pos - of_y;
  z_pos = spot.z_pos;

  surface = CL_Res_Surface::load(spot.desc.res_name.c_str(), *resource());

  if (speed != -1) {
    count.set_size(surface->get_no_sprs());
    count.set_speed(speed);
  }
}

void 
Hotspot::draw_offset(int x, int y, double s = 1.0)
{
  assert(surface);
  surface->put_screen((int)((x_pos + x) * s), (int)((y_pos + y) * s),
		      (int)(surface->get_width() * s), (int)(surface->get_height() * s),
		      ++count);
}

void
Hotspot::read_info(const char* filename)
{
  hotspot_pref temp;

  ifstream in(filename);
  
  if (!in) {
    perror(filename);
    exit(EXIT_FAILURE);
  }

  while(1) {
    in >> temp.name;
    in >> temp.x_pos;
    in >> temp.y_pos;
    in >> temp.speed;

    if (in.eof())
      break;

    offset[temp.name] = temp;
  }
}

/* EOF */
