// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef WORLD_HH
#define WORLD_HH

#include <ClanLib/clanlib.h>
#include <vector>
#include <iterator>

#include "PinguHolder.hh"
#include "GameObj.hh"
#include "WorldObj.hh"
#include "PLF.hh"
#include "Pingu.hh"
#include "Background.hh"
#include "ColMap.hh"
#include "Entrance.hh"
#include "Exit.hh"
#include "Hotspot.hh"
#include "Liquid.hh"
#include "Trap.hh"
#include "traps/traps.hh"
#include "Result.hh"
#include "particles/ParticleHolder.hh"

// World holds all object of the pingu world (pingus, traps, exits,
// entrances, etc.). It keeps control that all objects become time to
// move and can catch each other. 
class World : public GameObj
{
private:
  PinguMap*  map;
  Background* bg;

  bool do_armageddon;
  PinguIter armageddon_count;

  unsigned int released_pingus;
  unsigned int allowed_pingus;
  unsigned int pingus_out;
  int exit_world;

  Result* result;

  vector<WorldObj*> world_obj;

  vector<Entrance*> entrance;
  vector<Exit*>     exits;

  vector<Hotspot*>  hotspot;

  vector<Liquid*>   liquid;
  vector<Trap*>   traps;
  ParticleHolder particle;
  CL_InputSourceProvider* datafile;

  PinguHolder pingus;
  ColMap* colmap;

  // Private functions
  void draw_pingus(int x_offset, int y_offset, double s = 1.0);
  void draw_foreground(int x_offset, int y_offset, double s = 1.0) const;
public:
  World();
  virtual ~World();

  void    draw_offset(int x, int y, double s=1.0) const;
  void    save(void);
  void    load(void);
  void    load_data(CL_InputSourceProvider*);
  void    init(PLF*, Result&);
  void    let_move(void);
  void    armageddon(void);
  int     get_height(void);
  bool    is_finished(void);
  int     get_width(void);
  Result  write_results(void);
  void    print_status(void);
  PinguHolder* get_pingu_p(void);

  // Static Functions
  static void load_data();
};

#endif

/* EOF */
